@@ -25,7 +25,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <audacious/i18n.h>
-#include <audacious/gtk-compat.h>
 
 DuhFile *duh_file = NULL;
 static GMutex *dumblock;
@@ -47,11 +46,12 @@ static const gchar * const DUMB_defaults[] = {
 
 AUD_INPUT_PLUGIN
 (
-	.name = "DUMB Plugin " VERSION,
+	.name = N_("DUMB Plugin " VERSION),
+	.domain = PACKAGE,
 	.init = duh_init,
 	.cleanup = duh_cleanup,
 	.about = duh_about,
-	.settings = &preferences,
+	.prefs = &preferences,
 	.play = play_start,
 	.stop = stop,
 	.pause = duh_pause,
@@ -407,16 +407,9 @@ static gboolean play_start(InputPlayback *playback, const gchar *filename,
 				}
 			}
 			else
-			{
-				while (!stop_flag && playback->output->buffer_playing())
-					g_usleep(20000);
-			
 				break;
-			} 
 		}
 
-		playback->output->close_audio();
-
 		g_mutex_lock(control_mutex);
 		stop_flag = TRUE;
 		duh_file->eof = TRUE;
@@ -534,7 +527,7 @@ static PreferencesWidget settings[] = {
 	{WIDGET_COMBO_BOX, N_("Frequency:"),
 		.cfg_type = VALUE_INT,
 		.cfg = &dumb_config_gui.output_frequency,
-		.data = {.combo = {frequency_elements, G_N_ELEMENTS (frequency_elements), TRUE}},
+		.data = {.combo = {frequency_elements, G_N_ELEMENTS (frequency_elements)}},
 		.tooltip = N_("If you use dmix, pulseaudio or a similar stream "
 		              "mixer, choose the same frequency here to avoid "
 			      "useless resampling, otherwise pick whatever quality "
@@ -552,11 +545,8 @@ static PreferencesWidget settings[] = {
 };
 
 static PluginPreferences preferences = {
-	.domain = PACKAGE,
-	.title = N_("DUMB Preferences"),
-	.prefs = settings,
-	.n_prefs = G_N_ELEMENTS(settings),
-	.type = PREFERENCES_WINDOW,
+	.widgets = settings,
+	.n_widgets = G_N_ELEMENTS(settings),
 	.init = configure_init,
 	.apply = configure_apply,
 	.cleanup = configure_cleanup,
@@ -567,7 +557,7 @@ static void close_window(GtkWidget *widget, gpointer win) {
 }
 
 static gboolean escape_close(GtkWidget *widget, GdkEventKey *event, gpointer data) {
-	if (event->keyval == GDK_Escape) {
+	if (event->keyval == GDK_KEY_Escape) {
 		gtk_widget_destroy(GTK_WIDGET(widget));
 		return TRUE;
 	}
@@ -618,7 +608,7 @@ static void file_info_box(const gchar *filename) {
 	gtk_widget_set_size_request (window, 640, 480);
 	g_signal_connect(G_OBJECT(window), "destroy", G_CALLBACK(close_window), window);
 	g_signal_connect(G_OBJECT(window), "key-press-event", G_CALLBACK(escape_close), NULL);
-	window_vbox = gtk_vbox_new(FALSE, 6);
+	window_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
 	gtk_container_add (GTK_CONTAINER (window), window_vbox);
 
 	font_desc = pango_font_description_from_string ("monospace");
@@ -750,8 +740,7 @@ static void file_info_box(const gchar *filename) {
 	}
 
 	/* close button within hbox */
-
-	close_hbox = gtk_hbox_new(FALSE, 6);
+	close_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	close_button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
 	gtk_box_pack_end(GTK_BOX(close_hbox), close_button, FALSE, FALSE, 6);
 	g_signal_connect(G_OBJECT(close_button), "clicked", G_CALLBACK(close_window), window);
